==> geira_icons-1.0.3.tar.gz: lib/geira_icons.dart <==
library geira_icons;

import 'package:flutter/widgets.dart';
import 'package:geira_icons/icons_map.dart';

class GIcons {
  static const IconData notifications = const _GIconData(0xE000);
  static const IconData pencil = const _GIconData(0xE001);
  static const IconData wifi = const _GIconData(0xE004);
  static const IconData chat = const _GIconData(0xE005);
  static const IconData send = const _GIconData(0xE00A);
  static const IconData person = const _GIconData(0xE00B);
  static const IconData people = const _GIconData(0xE00C);
  static const IconData no_show = const _GIconData(0xE00D);
  static const IconData chart = const _GIconData(0xE013);
  static const IconData refresh = const _GIconData(0xE02C);
  static const IconData chevron_up = const _GIconData(0xE02D);
  static const IconData chevron_right = const _GIconData(0xE02E);
  static const IconData chevron_down = const _GIconData(0xE02F);
  static const IconData chevron_left = const _GIconData(0xE03A);
  static const IconData arrow_up = const _GIconData(0xE03B);
  static const IconData arrow_right = const _GIconData(0xE03C);
  static const IconData arrow_down = const _GIconData(0xE03D);
  static const IconData arrow_left = const _GIconData(0xE03E);
  static const IconData delete = const _GIconData(0xE03F);
  static const IconData volume = const _GIconData(0xE04C);
  static const IconData volume_up = const _GIconData(0xE04F);
  static const IconData volume_off = const _GIconData(0xE05A);
  static const IconData hearing = const _GIconData(0xE05B);
  static const IconData mic = const _GIconData(0xE05C);
  static const IconData mic_off = const _GIconData(0xE05D);
  static const IconData recording = const _GIconData(0xE05E);
  static const IconData play_arrow = const _GIconData(0xE06D);
  static const IconData pause = const _GIconData(0xE06E);
  static const IconData stop = const _GIconData(0xE06F);
  static const IconData skip_next = const _GIconData(0xE07A);
  static const IconData skip_previous = const _GIconData(0xE07B);
  static const IconData record = const _GIconData(0xE07C);
  static const IconData previous = const _GIconData(0xE08C);
  static const IconData next = const _GIconData(0xE08D);
  static const IconData list = const _GIconData(0xE09E);
  static const IconData sidebar_close = const _GIconData(0xE09F);
  static const IconData sidebar_open = const _GIconData(0xE0A0);
  static const IconData open_menu = const _GIconData(0xE0A1);
  static const IconData close_menu = const _GIconData(0xE0A2);
  static const IconData down_menu = const _GIconData(0xE0A3);
  static const IconData up_menu = const _GIconData(0xE0A4);
  static const IconData launch = const _GIconData(0xE0A5);
  static const IconData exit_to_app = const _GIconData(0xE0A6);
  static const IconData menu = const _GIconData(0xE0A7);
  static const IconData more_vert = const _GIconData(0xE0A8);
  static const IconData more_horiz = const _GIconData(0xE0A9);
  static const IconData cell_phone = const _GIconData(0xE0B8);
  static const IconData phone = const _GIconData(0xE0B9);
  static const IconData home = const _GIconData(0xE0BA);
  static const IconData language = const _GIconData(0xE0BB);
  static const IconData url = const _GIconData(0xE0BC);
  static const IconData lang = const _GIconData(0xE0BD);
  static const IconData lang_help = const _GIconData(0xE0BE);
  static const IconData map = const _GIconData(0xE0BF);
  static const IconData flag = const _GIconData(0xE0C9);
  static const IconData place = const _GIconData(0xE0CA);
  static const IconData mail = const _GIconData(0xE0CB);
  static const IconData award = const _GIconData(0xE0E7);
  static const IconData trophy = const _GIconData(0xE0E8);
  static const IconData shopping_cart = const _GIconData(0xE0F5);
  static const IconData payment = const _GIconData(0xE0F8);
  static const IconData deal = const _GIconData(0xE0FA);
  static const IconData gift = const _GIconData(0xE0FB);
  static const IconData time = const _GIconData(0xE0FC);
  static const IconData folder = const _GIconData(0xE111);
  static const IconData folder_open = const _GIconData(0xE112);
  static const IconData folder_add = const _GIconData(0xE113);
  static const IconData folder_special = const _GIconData(0xE114);
  static const IconData folder_delete = const _GIconData(0xE115);
  static const IconData page = const _GIconData(0xE117);
  static const IconData book = const _GIconData(0xE118);
  static const IconData test = const _GIconData(0xE119);
  static const IconData flash_cards = const _GIconData(0xE11A);
  static const IconData chevron_tr = const _GIconData(0xE130);
  static const IconData chevron_dr = const _GIconData(0xE131);
  static const IconData chevron_dl = const _GIconData(0xE132);
  static const IconData chevron_tl = const _GIconData(0xE133);
  static const IconData check = const _GIconData(0xE134);
  static const IconData check_outline = const _GIconData(0xE135);
  static const IconData checked = const _GIconData(0xE136);
  static const IconData unchecked = const _GIconData(0xE137);
  static const IconData rb_checked = const _GIconData(0xE139);
  static const IconData rb_unchecked = const _GIconData(0xE13A);
  static const IconData face_id = const _GIconData(0xE177);
  static const IconData ar_horiz = const _GIconData(0xE181);
  static const IconData ar_vert = const _GIconData(0xE182);
  static const IconData parking = const _GIconData(0xE19F);
  static const IconData bike = const _GIconData(0xE1A0);
  static const IconData walk = const _GIconData(0xE1A1);
  static const IconData girl = const _GIconData(0xE1A2);
  static const IconData boy = const _GIconData(0xE1A3);
  static const IconData disabled = const _GIconData(0xE1A4);
  static const IconData politician = const _GIconData(0xE1CC);
  static const IconData verified = const _GIconData(0xE1E1);
  static const IconData verified_user = const _GIconData(0xE1E2);
  static const IconData lock = const _GIconData(0xE1E3);
  static const IconData lock_open = const _GIconData(0xE1E4);
  static const IconData advertising = const _GIconData(0xE1FA);
  static const IconData no_advertising = const _GIconData(0xE1FB);
  static const IconData question_answer = const _GIconData(0xE201);
  static const IconData info = const _GIconData(0xE202);
  static const IconData help = const _GIconData(0xE203);
  static const IconData error = const _GIconData(0xE204);
  static const IconData visibility = const _GIconData(0xE205);
  static const IconData visibility_off = const _GIconData(0xE206);
  static const IconData thumb_up = const _GIconData(0xE207);
  static const IconData thumb_down = const _GIconData(0xE208);
  static const IconData favorite_border = const _GIconData(0xE209);
  static const IconData favorite = const _GIconData(0xE20A);
  static const IconData favorite_dislike = const _GIconData(0xE20B);
  static const IconData share = const _GIconData(0xE20C);
  static const IconData bookmark = const _GIconData(0xE20D);
  static const IconData star_border = const _GIconData(0xE20E);
  static const IconData star_half = const _GIconData(0xE20F);
  static const IconData star = const _GIconData(0xE210);
  static const IconData rate = const _GIconData(0xE211);
  static const IconData dictation = const _GIconData(0xE22F);
  static const IconData oral = const _GIconData(0xE230);
  static const IconData event_available = const _GIconData(0xE231);
  static const IconData upcoming = const _GIconData(0xE232);
  static const IconData past = const _GIconData(0xE233);
  static const IconData dashboard = const _GIconData(0xE23A);
  static const IconData campaign = const _GIconData(0xE23B);
  static const IconData push_pin = const _GIconData(0xE244);
  static const IconData search = const _GIconData(0xE245);
  static const IconData search_page = const _GIconData(0xE246);
  static const IconData camera = const _GIconData(0xE254);
  static const IconData images = const _GIconData(0xE256);
  static const IconData remove = const _GIconData(0xE257);
  static const IconData remove_circle = const _GIconData(0xE258);
  static const IconData add = const _GIconData(0xE259);
  static const IconData add_circle = const _GIconData(0xE25A);
  static const IconData close = const _GIconData(0xE25B);
  static const IconData cancel = const _GIconData(0xE25C);
  static const IconData filter = const _GIconData(0xE25D);
  static const IconData edit = const _GIconData(0xE25E);
  static const IconData settings = const _GIconData(0xE25F);
  static const IconData save = const _GIconData(0xE260);
  static const IconData television = const _GIconData(0xE26B);
  static const IconData store = const _GIconData(0xE26C);
  static const IconData drink = const _GIconData(0xE26D);
  static const IconData cashier = const _GIconData(0xE285);
  static const IconData full_square = const _GIconData(0xE287);
  static const IconData full_dot = const _GIconData(0xE288);
  static const IconData brightness_1 = const _GIconData(0xE289);
  static const IconData brightness_2 = const _GIconData(0xE28A);
  static const IconData brightness_3 = const _GIconData(0xE28B);
  static const IconData brightness_4 = const _GIconData(0xE28C);
  static const IconData brightness_5 = const _GIconData(0xE28D);
  static const IconData brightness_6 = const _GIconData(0xE28E);
  static const IconData brightness_7 = const _GIconData(0xE28F);
  static const IconData facebook = const _GIconData(0xE291);
  static const IconData twitter = const _GIconData(0xE292);
  static const IconData youtube = const _GIconData(0xE293);
  static const IconData instagram = const _GIconData(0xE294);
  static const IconData gitlab = const _GIconData(0xE2A1);
  static const IconData npm = const _GIconData(0xE2A2);
  static const IconData apple_logo = const _GIconData(0xE2A3);
  static const IconData facebook_logo = const _GIconData(0xE2A4);
  static const IconData google_logo = const _GIconData(0xE2A5);

  static IconData fromString(String key) {
    int codePoint = iconMap[key];
    if (codePoint == null) return null;
    return _GIconData(codePoint);
  }

  IconData operator [](String key) {
    int codePoint = iconMap[key];
    if (codePoint == null) return null;
    return _GIconData(codePoint);
  }

  static List<String> getIconsName() {
    return iconMap.keys.toList();
  }
}

class _GIconData extends IconData {
  const _GIconData(int codePoint)
      : super(
          codePoint,
          fontFamily: 'Geira Icons',
          fontPackage: 'geira_icons',
        );
}

==> geira_icons-2.0.0.tar.gz: lib/geira_icons.dart <==
library geira_icons;

import 'package:flutter/widgets.dart';
import 'package:geira_icons/icons_map.dart';

class GIcons {
  static const IconData notifications = const _GIconData(0xE000);
  static const IconData pencil = const _GIconData(0xE001);
  static const IconData wifi = const _GIconData(0xE004);
  static const IconData chat = const _GIconData(0xE005);
  static const IconData send = const _GIconData(0xE00A);
  static const IconData person = const _GIconData(0xE00B);
  static const IconData people = const _GIconData(0xE00C);
  static const IconData no_show = const _GIconData(0xE00D);
  static const IconData chart = const _GIconData(0xE013);
  static const IconData refresh = const _GIconData(0xE02C);
  static const IconData chevron_up = const _GIconData(0xE02D);
  static const IconData chevron_right = const _GIconData(0xE02E);
  static const IconData chevron_down = const _GIconData(0xE02F);
  static const IconData chevron_left = const _GIconData(0xE03A);
  static const IconData arrow_up = const _GIconData(0xE03B);
  static const IconData arrow_right = const _GIconData(0xE03C);
  static const IconData arrow_down = const _GIconData(0xE03D);
  static const IconData arrow_left = const _GIconData(0xE03E);
  static const IconData delete = const _GIconData(0xE03F);
  static const IconData volume = const _GIconData(0xE04C);
  static const IconData volume_up = const _GIconData(0xE04F);
  static const IconData volume_off = const _GIconData(0xE05A);
  static const IconData hearing = const _GIconData(0xE05B);
  static const IconData mic = const _GIconData(0xE05C);
  static const IconData mic_off = const _GIconData(0xE05D);
  static const IconData recording = const _GIconData(0xE05E);
  static const IconData play_arrow = const _GIconData(0xE06D);
  static const IconData pause = const _GIconData(0xE06E);
  static const IconData stop = const _GIconData(0xE06F);
  static const IconData skip_next = const _GIconData(0xE07A);
  static const IconData skip_previous = const _GIconData(0xE07B);
  static const IconData record = const _GIconData(0xE07C);
  static const IconData previous = const _GIconData(0xE08C);
  static const IconData next = const _GIconData(0xE08D);
  static const IconData list = const _GIconData(0xE09E);
  static const IconData sidebar_close = const _GIconData(0xE09F);
  static const IconData sidebar_open = const _GIconData(0xE0A0);
  static const IconData open_menu = const _GIconData(0xE0A1);
  static const IconData close_menu = const _GIconData(0xE0A2);
  static const IconData down_menu = const _GIconData(0xE0A3);
  static const IconData up_menu = const _GIconData(0xE0A4);
  static const IconData launch = const _GIconData(0xE0A5);
  static const IconData exit_to_app = const _GIconData(0xE0A6);
  static const IconData menu = const _GIconData(0xE0A7);
  static const IconData more_vert = const _GIconData(0xE0A8);
  static const IconData more_horiz = const _GIconData(0xE0A9);
  static const IconData cell_phone = const _GIconData(0xE0B8);
  static const IconData phone = const _GIconData(0xE0B9);
  static const IconData home = const _GIconData(0xE0BA);
  static const IconData language = const _GIconData(0xE0BB);
  static const IconData url = const _GIconData(0xE0BC);
  static const IconData lang = const _GIconData(0xE0BD);
  static const IconData lang_help = const _GIconData(0xE0BE);
  static const IconData map = const _GIconData(0xE0BF);
  static const IconData flag = const _GIconData(0xE0C9);
  static const IconData place = const _GIconData(0xE0CA);
  static const IconData mail = const _GIconData(0xE0CB);
  static const IconData award = const _GIconData(0xE0E7);
  static const IconData trophy = const _GIconData(0xE0E8);
  static const IconData shopping_cart = const _GIconData(0xE0F5);
  static const IconData payment = const _GIconData(0xE0F8);
  static const IconData deal = const _GIconData(0xE0FA);
  static const IconData gift = const _GIconData(0xE0FB);
  static const IconData time = const _GIconData(0xE0FC);
  static const IconData folder = const _GIconData(0xE111);
  static const IconData folder_open = const _GIconData(0xE112);
  static const IconData folder_add = const _GIconData(0xE113);
  static const IconData folder_special = const _GIconData(0xE114);
  static const IconData folder_delete = const _GIconData(0xE115);
  static const IconData page = const _GIconData(0xE117);
  static const IconData book = const _GIconData(0xE118);
  static const IconData test = const _GIconData(0xE119);
  static const IconData flash_cards = const _GIconData(0xE11A);
  static const IconData chevron_tr = const _GIconData(0xE130);
  static const IconData chevron_dr = const _GIconData(0xE131);
  static const IconData chevron_dl = const _GIconData(0xE132);
  static const IconData chevron_tl = const _GIconData(0xE133);
  static const IconData check = const _GIconData(0xE134);
  static const IconData check_outline = const _GIconData(0xE135);
  static const IconData checked = const _GIconData(0xE136);
  static const IconData unchecked = const _GIconData(0xE137);
  static const IconData rb_checked = const _GIconData(0xE139);
  static const IconData rb_unchecked = const _GIconData(0xE13A);
  static const IconData face_id = const _GIconData(0xE177);
  static const IconData ar_horiz = const _GIconData(0xE181);
  static const IconData ar_vert = const _GIconData(0xE182);
  static const IconData parking = const _GIconData(0xE19F);
  static const IconData bike = const _GIconData(0xE1A0);
  static const IconData walk = const _GIconData(0xE1A1);
  static const IconData girl = const _GIconData(0xE1A2);
  static const IconData boy = const _GIconData(0xE1A3);
  static const IconData disabled = const _GIconData(0xE1A4);
  static const IconData politician = const _GIconData(0xE1CC);
  static const IconData verified = const _GIconData(0xE1E1);
  static const IconData verified_user = const _GIconData(0xE1E2);
  static const IconData lock = const _GIconData(0xE1E3);
  static const IconData lock_open = const _GIconData(0xE1E4);
  static const IconData advertising = const _GIconData(0xE1FA);
  static const IconData no_advertising = const _GIconData(0xE1FB);
  static const IconData question_answer = const _GIconData(0xE201);
  static const IconData info = const _GIconData(0xE202);
  static const IconData help = const _GIconData(0xE203);
  static const IconData error = const _GIconData(0xE204);
  static const IconData visibility = const _GIconData(0xE205);
  static const IconData visibility_off = const _GIconData(0xE206);
  static const IconData thumb_up = const _GIconData(0xE207);
  static const IconData thumb_down = const _GIconData(0xE208);
  static const IconData favorite_border = const _GIconData(0xE209);
  static const IconData favorite = const _GIconData(0xE20A);
  static const IconData favorite_dislike = const _GIconData(0xE20B);
  static const IconData share = const _GIconData(0xE20C);
  static const IconData bookmark = const _GIconData(0xE20D);
  static const IconData star_border = const _GIconData(0xE20E);
  static const IconData star_half = const _GIconData(0xE20F);
  static const IconData star = const _GIconData(0xE210);
  static const IconData rate = const _GIconData(0xE211);
  static const IconData dictation = const _GIconData(0xE22F);
  static const IconData oral = const _GIconData(0xE230);
  static const IconData event_available = const _GIconData(0xE231);
  static const IconData upcoming = const _GIconData(0xE232);
  static const IconData past = const _GIconData(0xE233);
  static const IconData dashboard = const _GIconData(0xE23A);
  static const IconData campaign = const _GIconData(0xE23B);
  static const IconData push_pin = const _GIconData(0xE244);
  static const IconData search = const _GIconData(0xE245);
  static const IconData search_page = const _GIconData(0xE246);
  static const IconData camera = const _GIconData(0xE254);
  static const IconData images = const _GIconData(0xE256);
  static const IconData remove = const _GIconData(0xE257);
  static const IconData remove_circle = const _GIconData(0xE258);
  static const IconData add = const _GIconData(0xE259);
  static const IconData add_circle = const _GIconData(0xE25A);
  static const IconData close = const _GIconData(0xE25B);
  static const IconData cancel = const _GIconData(0xE25C);
  static const IconData filter = const _GIconData(0xE25D);
  static const IconData edit = const _GIconData(0xE25E);
  static const IconData settings = const _GIconData(0xE25F);
  static const IconData save = const _GIconData(0xE260);
  static const IconData television = const _GIconData(0xE26B);
  static const IconData store = const _GIconData(0xE26C);
  static const IconData drink = const _GIconData(0xE26D);
  static const IconData cashier = const _GIconData(0xE285);
  static const IconData full_square = const _GIconData(0xE287);
  static const IconData full_dot = const _GIconData(0xE288);
  static const IconData brightness_1 = const _GIconData(0xE289);
  static const IconData brightness_2 = const _GIconData(0xE28A);
  static const IconData brightness_3 = const _GIconData(0xE28B);
  static const IconData brightness_4 = const _GIconData(0xE28C);
  static const IconData brightness_5 = const _GIconData(0xE28D);
  static const IconData brightness_6 = const _GIconData(0xE28E);
  static const IconData brightness_7 = const _GIconData(0xE28F);
  static const IconData facebook = const _GIconData(0xE291);
  static const IconData twitter = const _GIconData(0xE292);
  static const IconData youtube = const _GIconData(0xE293);
  static const IconData instagram = const _GIconData(0xE294);
  static const IconData gitlab = const _GIconData(0xE2A1);
  static const IconData npm = const _GIconData(0xE2A2);
  static const IconData apple_logo = const _GIconData(0xE2A3);
  static const IconData facebook_logo = const _GIconData(0xE2A4);
  static const IconData google_logo = const _GIconData(0xE2A5);

  static IconData? fromString(String key) {
    int? codePoint = iconMap[key];
    if (codePoint == null) return null;
    return _GIconData(codePoint);
  }

  IconData? operator [](String key) {
    int? codePoint = iconMap[key];
    if (codePoint == null) return null;
    return _GIconData(codePoint);
  }

  static List<String> getIconsName() {
    return iconMap.keys.toList();
  }
}

class _GIconData extends IconData {
  const _GIconData(int codePoint)
      : super(
          codePoint,
          fontFamily: 'Geira Icons',
          fontPackage: 'geira_icons',
        );
}
